R/geom_half_circle.R, R/stat-half-circle.R
geom_half_circle.RdHalf-Circles with pre-defined radii.
geom_half_circle(mapping = NULL, data = NULL, stat = "half_circle", position = "identity", n = 180, na.rm = FALSE, show.legend = NA, inherit.aes = TRUE, ...) stat_half_circle(mapping = NULL, data = NULL, geom = "half_circle", position = "identity", n = 180, na.rm = FALSE, show.legend = NA, inherit.aes = TRUE, ...)
| mapping | Set of aesthetic mappings created by |
|---|---|
| data | The data to be displayed in this layer. There are three options: If A A |
| stat | The statistical transformation to use on the data for this layer, as a string. |
| position | Position adjustment, either as a string, or the result of a call to a position adjustment function. |
| n | The number of points calculated for the circle polygon, defaults to 180. |
| na.rm | If |
| show.legend | logical. Should this layer be included in the legends?
|
| inherit.aes | If |
| ... | Other arguments passed on to |
| geom | The geometric object to use display the data |
geom_half_circle understands the following aesthetics (required aesthetics are in bold):
- **x** - x-coordinate of center - **y** - y-coordinate of center - **r** - radius - color - fill - linetype - alpha